@@ -4,7 +4,7 @@ import sys
 
 # Replaced during install; must be a single line
 # fmt: off
-DEBPUTY_ROOT_DIR = pathlib.Path(__file__).parent
+DEBPUTY_ROOT_DIR = pathlib.Path(__file__).parent / 'src'
 # fmt: on
 
 if __name__ == "__main__":
