@@ -38,7 +38,7 @@ def detect_grantlee_dependencies(
             continue
         # Delta: The original code recurses and then checks for "grantee/VERSION".
         # Code here assumes that was just File::Find being used as a dir iterator.
-        for child in grantlee_root_path.iterdir:
+        for child in grantlee_root_path.iterdir():
             if not _RE_GRANTLEE_VERSION.fullmatch(child.name):
                 continue
             version = child.name
