@@ -689,10 +689,10 @@ def _add_known_packaging_data(
 
 
 def _scan_debian_dir(debian_dir: VirtualPath) -> Iterator[VirtualPath]:
-    for p in debian_dir.iterdir:
+    for p in debian_dir.iterdir():
         yield p
         if p.is_dir and p.path in ("debian/source", "debian/tests"):
-            yield from p.iterdir
+            yield from p.iterdir()
 
 
 _POST_FORMATTING_REWRITE = {
