@@ -10,6 +10,7 @@ import traceback
 from tempfile import TemporaryDirectory
 from typing import (
     Any,
+    Callable,
     NoReturn,
     NamedTuple,
     Literal,
@@ -53,6 +54,7 @@ from debputy.plugin.api.spec import (
     INTEGRATION_MODE_FULL,
 )
 
+autocomplete: "Callable[[argparse.ArgumentParser], None]"
 try:
     from argcomplete import autocomplete
 except ImportError:
@@ -439,7 +441,7 @@ def _find_plugins_and_tests_in_source_package(
             continue
         had_plugin_dir = True
         dest_dir = os.path.join("debian", binary_package.name)
-        for path in debputy_plugins_dir.iterdir:
+        for path in debputy_plugins_dir.iterdir():
             if not path.is_file or not path.name.endswith((".json", ".json.in")):
                 continue
             plugin_metadata = parse_json_plugin_desc(path.path)
