@@ -135,8 +135,8 @@ def _plugin_cmd_list_plugins(context: CommandContext) -> None:
     assert output_format in {"text", "csv"}
     with _stream_to_pager(context.parsed_args) as (fd, fo):
         fo.print_list_table(
-            ["Plugin Name", "Plugin Path"],
-            [(p.plugin_name, p.plugin_path) for p in plugin_metadata_entries],
+            headers=("Plugin Name", "Plugin Path"),
+            rows=tuple((p.plugin_name, p.plugin_path) for p in plugin_metadata_entries),
         )
 
 
@@ -194,15 +194,14 @@ def _plugin_cmd_list_uppf(context: CommandContext) -> None:
 
     with _stream_to_pager(context.parsed_args) as (fd, fo):
         if used_ppfs:
-            headers: Sequence[str | tuple[str, str]] = [
-                "File",
-                "Matched Stem",
-                "Installed Into",
-                "Installed As",
-            ]
             fo.print_list_table(
-                headers,
-                [
+                headers=(
+                    "File",
+                    "Matched Stem",
+                    "Installed Into",
+                    "Installed As",
+                ),
+                rows=tuple(
                     (
                         ppf.path.path,
                         ppf.definition.stem,
@@ -212,20 +211,19 @@ def _plugin_cmd_list_uppf(context: CommandContext) -> None:
                     for ppf in sorted(
                         used_ppfs, key=operator.attrgetter("package_name")
                     )
-                ],
+                ),
             )
 
         if inactive_ppfs:
-            headers: Sequence[str | tuple[str, str]] = [
-                "UNUSED FILE",
-                "Matched Stem",
-                "Installed Into",
-                "Could Be Installed As",
-                "If B-D Had",
-            ]
             fo.print_list_table(
-                headers,
-                [
+                headers=(
+                    "UNUSED FILE",
+                    "Matched Stem",
+                    "Installed Into",
+                    "Could Be Installed As",
+                    "If B-D Had",
+                ),
+                rows=tuple(
                     (
                         f"~{ppf.path.path}~",
                         ppf.definition.stem,
@@ -236,7 +234,7 @@ def _plugin_cmd_list_uppf(context: CommandContext) -> None:
                     for ppf in sorted(
                         inactive_ppfs, key=operator.attrgetter("package_name")
                     )
-                ],
+                ),
             )
 
 
@@ -249,16 +247,15 @@ def _plugin_cmd_list_ppf(context: CommandContext) -> None:
     ppfs: Iterable[PackagerProvidedFileClassSpec]
     ppfs = context.load_plugins().packager_provided_files.values()
     with _stream_to_pager(context.parsed_args) as (fd, fo):
-        headers: Sequence[str | tuple[str, str]] = [
-            "Stem",
-            "Installed As",
-            ("Mode", ">"),
-            "Features",
-            "Provided by",
-        ]
         fo.print_list_table(
-            headers,
-            [
+            headers=(
+                "Stem",
+                "Installed As",
+                ("Mode", ">"),
+                "Features",
+                "Provided by",
+            ),
+            rows=tuple(
                 (
                     ppf.stem,
                     _path(ppf.installed_as_format),
@@ -267,7 +264,7 @@ def _plugin_cmd_list_ppf(context: CommandContext) -> None:
                     ppf.debputy_plugin_metadata.plugin_name,
                 )
                 for ppf in sorted(ppfs, key=operator.attrgetter("stem"))
-            ],
+            ),
         )
 
         if os.path.isdir("debian/") and fo.output_format == "text":
@@ -295,11 +292,11 @@ def _plugin_cmd_list_metadata_detectors(context: CommandContext) -> None:
 
     with _stream_to_pager(context.parsed_args) as (fd, fo):
         fo.print_list_table(
-            ["Provided by", "Detector Id"],
-            [
+            headers=("Provided by", "Detector Id"),
+            rows=tuple(
                 (md.plugin_metadata.plugin_name, md.detector_id)
                 for md in sorted(mds, key=_sort_key)
-            ],
+            ),
         )
 
 
@@ -357,8 +354,13 @@ def plugin_cmd_list_manifest_variables(context: CommandContext) -> None:
 
     with _stream_to_pager(context.parsed_args) as (fd, fo):
         fo.print_list_table(
-            ["Variable (use via: `{{ NAME }}`)", "Value", "Flag", "Provided by"],
-            [
+            headers=(
+                "Variable (use via: `{{ NAME }}`)",
+                "Value",
+                "Flag",
+                "Provided by",
+            ),
+            rows=tuple(
                 (
                     k,
                     _resolve_variable_for_list(substitution, var),
@@ -367,7 +369,7 @@ def plugin_cmd_list_manifest_variables(context: CommandContext) -> None:
                 )
                 for k, var in sorted(variables.items())
                 if _include_var(var)
-            ],
+            ),
         )
 
         fo.print()
@@ -386,15 +388,15 @@ def plugin_cmd_list_manifest_variables(context: CommandContext) -> None:
         ]
 
         fo.print_list_table(
-            ["Variable type", "Value", "Option"],
-            [
+            headers=("Variable type", "Value", "Option"),
+            rows=tuple(
                 (
                     fname,
                     _render_list_filter(value or show_all_vars),
                     f"{option} OR --show-all-variables",
                 )
                 for fname, value, option in filters
-            ],
+            ),
         )
 
 
@@ -449,8 +451,8 @@ def _plugin_cmd_list_manifest_rules(context: CommandContext) -> None:
 
     with _stream_to_pager(context.parsed_args) as (fd, fo):
         fo.print_list_table(
-            ["Rule Name", "Rule Type", "Provided By"],
-            [
+            headers=("Rule Name", "Rule Type", "Provided By"),
+            rows=tuple(
                 (
                     rn,
                     parser_type_name(rt),
@@ -458,7 +460,7 @@ def _plugin_cmd_list_manifest_rules(context: CommandContext) -> None:
                 )
                 for rt, pt in parsers
                 for rn in pt.registered_keywords()
-            ],
+            ),
         )
 
 
@@ -472,14 +474,14 @@ def _plugin_cmd_list_automatic_discard_rules(context: CommandContext) -> None:
 
     with _stream_to_pager(context.parsed_args) as (fd, fo):
         fo.print_list_table(
-            ["Name", "Provided By"],
-            [
+            headers=("Name", "Provided By"),
+            rows=tuple(
                 (
                     name,
                     ppdr.plugin_metadata.plugin_name,
                 )
                 for name, ppdr in auto_discard_rules.items()
-            ],
+            ),
         )
 
 
@@ -697,7 +699,7 @@ def _plugin_cmd_show_ppf(context: CommandContext) -> None:
             (f"debian/{first_pkg}.my.custom.name.{ppf.stem}", "my.custom.name")
         )
     if ppf.allow_architecture_segment:
-        example_files.append((f"debian/{first_pkg}.{ppf.stem}.amd64", first_pkg)),
+        example_files.append((f"debian/{first_pkg}.{ppf.stem}.amd64", first_pkg))
         if ppf.allow_name_segment:
             example_files.append(
                 (
@@ -720,7 +722,10 @@ def _plugin_cmd_show_ppf(context: CommandContext) -> None:
         dest_path = "/".join(dest).lstrip(".")
         rendered_examples.append((example_file, dest_path))
 
-    fo.print_list_table(["Source file", "Installed As"], rendered_examples)
+    fo.print_list_table(
+        headers=("Source file", "Installed As"),
+        rows=rendered_examples,
+    )
 
     if doc_uris:
         fo.print()
@@ -1034,15 +1039,15 @@ def _plugin_cmd_list_type_mappings(context: CommandContext) -> None:
 
     with _stream_to_pager(context.parsed_args) as (fd, fo):
         fo.print_list_table(
-            ["Type", "Base Type", "Provided By"],
-            [
+            headers=("Type", "Base Type", "Provided By"),
+            rows=tuple(
                 (
                     target_type.__name__,
                     render_source_type(type_mapping.mapped_type.source_type),
                     type_mapping.plugin_metadata.plugin_name,
                 )
                 for target_type, type_mapping in type_mappings.items()
-            ],
+            ),
         )
 
 
