@@ -250,7 +250,7 @@ def handle_perl_code(
 
 def usr_local_transformation(dctrl: BinaryPackage, fs_root: VirtualPath) -> None:
     path = fs_root.lookup("./usr/local")
-    if path and any(path.iterdir):
+    if path and any(path.iterdir()):
         # There are two key issues:
         #  1) Getting the generated maintscript carried on to the final maintscript
         #  2) Making sure that manifest created directories do not trigger the "unused error".
@@ -275,7 +275,7 @@ def _find_and_analyze_systemd_service_files(
         system_dir = fs_root.lookup(d)
         if not system_dir:
             continue
-        for child in system_dir.iterdir:
+        for child in system_dir.iterdir():
             if child.is_symlink:
                 dest = os.path.basename(child.readlink())
                 aliases[dest].append(child.name)
@@ -480,7 +480,7 @@ def install_upstream_changelog(
             # Accept that as the canonical one.
             return
         upstream_changelog = _detect_upstream_changelog(
-            p.name for p in bdir.iterdir if p.is_file and p.has_fs_path and p.size > 0
+            p.name for p in bdir.iterdir() if p.is_file and p.has_fs_path and p.size > 0
         )
         if upstream_changelog:
             p = bdir.lookup(upstream_changelog)
@@ -493,7 +493,7 @@ def install_upstream_changelog(
             continue
         changelog_name = _detect_upstream_changelog(
             p.name
-            for p in dir_path.iterdir
+            for p in dir_path.iterdir()
             if p.is_file and p.has_fs_path and p.size > 0
         )
         if changelog_name:
