@@ -1597,7 +1597,7 @@ def migrate_doc_base_files(
     # ignore the dh_make ".EX" file if one should still be present. The dh_installdocs tool ignores it too.
     possible_effected_doc_base_files = [
         f
-        for f in debian_dir.iterdir
+        for f in debian_dir.iterdir()
         if (
             (".doc-base." in f.name or f.name.startswith("doc-base."))
             and not f.name.endswith("doc-base.EX")
