@@ -159,7 +159,7 @@ class PathMetadataReferenceImplementation(PathMetadataReference[PMT]):
 
     def __init__(
         self,
-        owning_path: VirtualPath,
+        owning_path: "VirtualPathBase",
         current_plugin: str,
         path_metadata_value: PathMetadataValue[PMT],
     ) -> None:
@@ -251,13 +251,14 @@ def _split_path(path: str) -> tuple[bool, bool, list[str]]:
     return absolute, must_be_dir, path_parts
 
 
-def _root(path: VP) -> VP:
+def _root(path: VP) -> "VirtualPathBase":
     current = path
-    while True:
+    while not current.is_root_dir():
         parent = current.parent_dir
-        if parent is None:
-            return current
+        assert parent is not None  # type hint
         current = parent
+    assert isinstance(current, VirtualPathBase)
+    return current
 
 
 def _check_fs_path_is_file(
@@ -341,6 +342,14 @@ class VirtualPathBase(VirtualPath, ABC):
                 " Debputy Virtual File system is R/O."
             )
 
+    @property
+    def is_detached(self) -> bool:
+        raise NotImplementedError
+
+    def is_root_dir(self) -> bool:
+        # The root directory is never detachable in the current setup
+        return not self.is_detached and self.parent_dir is None
+
     def lookup(self, path: str) -> Optional["VirtualPathBase"]:
         match, missing = self.attempt_lookup(path)
         if missing:
@@ -361,13 +370,14 @@ class VirtualPathBase(VirtualPath, ABC):
             if dir_part == ".":
                 continue
             if dir_part == "..":
-                p = current.parent_dir
-                if p is None:
+                if current.is_root_dir():
                     raise ValueError(f'The path "{path}" escapes the root dir')
-                current = p
+                p = current.parent_dir
+                assert p is not None  # type hint
+                current = cast("VirtualPathBase", p)
                 continue
             try:
-                current = current[dir_part]
+                current = cast("VirtualPathBase", current[dir_part])
             except KeyError:
                 path_parts.append(dir_part)
                 path_parts.reverse()
@@ -392,7 +402,9 @@ class VirtualPathBase(VirtualPath, ABC):
                 if link_absolute:
                     current = _root(current)
                 else:
-                    current = assume_not_none(current.parent_dir)
+                    current = cast(
+                        "VirtualPathBase", assume_not_none(current.parent_dir)
+                    )
                 link_path_parts.reverse()
                 path_parts.extend(link_path_parts)
         return current, []
@@ -424,9 +436,9 @@ class VirtualPathBase(VirtualPath, ABC):
 
         if not self.is_dir:
             raise TypeError(f"{self._orphan_safe_path()} is not a directory")
-        if any(self.iterdir):
+        if any(self.iterdir()):
             return
-        parent_dir = assume_not_none(self.parent_dir)
+        parent_dir = typing.cast("VirtualPathBase", assume_not_none(self.parent_dir))
 
         # Recursive does not matter; we already know the directory is empty.
         self.unlink()
@@ -439,14 +451,7 @@ class VirtualPathBase(VirtualPath, ABC):
     def _current_plugin(self) -> str:
         if self.is_detached:
             raise TypeError("Cannot resolve the current plugin; path is detached")
-        current = self
-        while True:
-            next_parent = current.parent_dir
-            if next_parent is None:
-                break
-            current = next_parent
-        assert current is not None
-        return cast("FSRootDir", current)._current_plugin()
+        return cast("FSRootDir", _root(self))._current_plugin()
 
     @overload
     def open_child(
@@ -601,7 +606,6 @@ class FSPath(VirtualPathBase, ABC):
         self._basename = new_name
         self.parent_dir = parent
 
-    @property
     def iterdir(self) -> Iterable["FSPath"]:
         if self._children is not None:
             yield from self._children.values()
@@ -611,12 +615,12 @@ class FSPath(VirtualPathBase, ABC):
         if not self.is_dir:
             return
         by_basename = BY_BASENAME
-        stack = sorted(self.iterdir, key=by_basename, reverse=True)
+        stack = sorted(self.iterdir(), key=by_basename, reverse=True)
         while stack:
             current = stack.pop()
             yield current
             if current.is_dir and not current.is_detached:
-                stack.extend(sorted(current.iterdir, key=by_basename, reverse=True))
+                stack.extend(sorted(current.iterdir(), key=by_basename, reverse=True))
 
     def walk(self) -> Iterable[tuple["FSPath", list["FSPath"]]]:
         # FIXME: can this be more "os.walk"-like without making it harder to implement?
@@ -627,7 +631,7 @@ class FSPath(VirtualPathBase, ABC):
         stack = [self]
         while stack:
             current = stack.pop()
-            children = sorted(current.iterdir, key=by_basename)
+            children = sorted(current.iterdir(), key=by_basename)
             assert not children or current.is_dir
             yield current, children
             # Removing the directory counts as discarding the children.
@@ -1075,7 +1079,7 @@ class FSPath(VirtualPathBase, ABC):
         """
         if self.is_detached:
             return
-        if not recursive and any(self.iterdir):
+        if not recursive and any(self.iterdir()):
             raise ValueError(
                 f'Refusing to unlink "{self.path}": The directory was not empty and recursive was False'
             )
@@ -1884,19 +1888,20 @@ class OSFSOverlayBase(VirtualPathBase, Generic[FSP]):
         )
 
     def all_paths(self) -> Iterable["OSFSControlPath"]:
-        yield self
+        yield cast("OSFSControlPath", self)
         if not self.is_dir:
             return
-        stack = list(self.iterdir)
+        stack = list(self.iterdir())
         stack.reverse()
         while stack:
-            current = stack.pop()
+            current = cast("OSFSControlPath", stack.pop())
             yield current
             if current.is_dir:
-                stack.extend(reversed(list(current.iterdir)))
+                stack.extend(reversed(list(current.iterdir())))
 
     def _resolve_children(
-        self, new_child: Callable[[str, str, FSP], FSC]
+        self,
+        new_child: Callable[[str, str, FSP], FSC],
     ) -> Mapping[str, FSC]:
         if not self.is_dir:
             return {}
@@ -1911,12 +1916,12 @@ class OSFSOverlayBase(VirtualPathBase, Generic[FSP]):
             children[name] = new_child(
                 child_path,
                 child_fs_path,
-                self,
+                cast("FSP", self),
             )
         return children
 
 
-class OSFSROOverlay(OSFSOverlayBase["FSROOverlay"]):
+class OSFSROOverlay(OSFSOverlayBase["OSFSROOverlay"]):
     __slots__ = (
         "_stat_cache",
         "_readlink_cache",
@@ -1940,7 +1945,6 @@ class OSFSROOverlay(OSFSOverlayBase["FSROOverlay"]):
     def create_root_dir(cls, path: str, fs_path: str) -> "OSFSROOverlay":
         return OSFSROOverlay(path, fs_path, None)
 
-    @property
     def iterdir(self) -> Iterable["OSFSROOverlay"]:
         if not self.is_dir:
             return
@@ -1955,18 +1959,19 @@ class OSFSROOverlay(OSFSOverlayBase["FSROOverlay"]):
             self._ensure_children_are_resolved()
 
         absolute, _, path_parts = _split_path(path)
-        current = cast("FSROOverlay", _root(self)) if absolute else self
+        current = cast("OSFSROOverlay", _root(self)) if absolute else self
         for no, dir_part in enumerate(path_parts):
             if dir_part == ".":
                 continue
             if dir_part == "..":
-                p = current.parent_dir
-                if p is None:
+                if current.is_root_dir():
                     raise ValueError(f'The path "{path}" escapes the root dir')
-                current = cast("FSROOverlay", p)
+                p = current.parent_dir
+                assert p is not None  # Type hint
+                current = cast("OSFSROOverlay", p)
                 continue
             try:
-                current = current[dir_part]
+                current = cast("OSFSROOverlay", current[dir_part])
             except KeyError:
                 return None
         return current
@@ -1989,7 +1994,7 @@ class OSFSROOverlay(OSFSOverlayBase["FSROOverlay"]):
             self._ensure_children_are_resolved()
         if isinstance(key, FSPath):
             key = key.name
-        return self._children[key]
+        return assume_not_none(self._children)[key]
 
     def __delitem__(self, key) -> Never:
         self._error_ro_fs()
@@ -2088,9 +2093,8 @@ class OSFSROOverlayRootDir(OSFSROOverlay):
             yield r
 
 
-class OSFSControlPath(OSFSOverlayBase["FSControlPath"]):
+class OSFSControlPath(OSFSOverlayBase["OSFSControlPath"]):
 
-    @property
     def iterdir(self) -> Iterable["OSFSControlPath"]:
         if not self.is_dir:
             return
@@ -2103,18 +2107,19 @@ class OSFSControlPath(OSFSOverlayBase["FSControlPath"]):
             return None
 
         absolute, _, path_parts = _split_path(path)
-        current = cast("FSControlPath", _root(self)) if absolute else self
+        current = cast("OSFSControlPath", _root(self)) if absolute else self
         for no, dir_part in enumerate(path_parts):
             if dir_part == ".":
                 continue
             if dir_part == "..":
-                p = current.parent_dir
-                if p is None:
+                if current.is_root_dir():
                     raise ValueError(f'The path "{path}" escapes the root dir')
-                current = cast("FSControlPath", p)
+                p = current.parent_dir
+                assert p is not None  # type hint
+                current = cast("OSFSControlPath", p)
                 continue
             try:
-                current = current[dir_part]
+                current = cast("OSFSControlPath", current[dir_part])
             except KeyError:
                 return None
         return current
@@ -2291,7 +2296,7 @@ class FSControlRootDir(OSFSControlPath):
                 follow_symlinks=True,
             )
             os.chmod(target_path, mode)
-        return cast("FSControlPath", self[name])
+        return cast("OSFSControlPath", self[name])
 
 
 def as_path_def(pd: str | PathDef) -> PathDef:
