@@ -307,10 +307,11 @@ class SourcePathMatcher:
                 break
             # We cannot trust a "NOT_DISCARDED" until we check its parent (the directory could
             # be excluded without the files in it triggering the rule).
-            parent_dir = current_path.parent_dir
-            if not parent_dir:
+            if current_path.is_root_dir():
                 verdict = DiscardState.NOT_DISCARDED
                 break
+            parent_dir = current_path.parent_dir
+            assert parent_dir is not None  # type hint
             current_path = parent_dir
         if cache_misses:
             for p in cache_misses:
@@ -365,12 +366,12 @@ class SourcePathMatcher:
             discarded_paths.discard(fs_path)
 
     def detect_missing(self, search_dir: "VirtualPath") -> Iterator["VirtualPath"]:
-        stack = list(search_dir.iterdir)
+        stack = list(search_dir.iterdir())
         while stack:
             m = stack.pop()
             if m.is_dir:
                 s_len = len(stack)
-                stack.extend(m.iterdir)
+                stack.extend(m.iterdir())
 
                 if s_len == len(stack) and not self.is_reserved(m):
                     # "Explicitly" empty dir
@@ -471,7 +472,7 @@ def _resolve_path(
         ):
             if dir_only_match and not matched_path.is_dir:
                 continue
-            if matched_path.parent_dir is None:
+            if matched_path.is_root_dir():
                 if match_rule is MATCH_ANYTHING:
                     continue
                 _error(
@@ -769,7 +770,7 @@ class InstallRule(DebputyDispatchableType):
         )
         if not direct_matched_path.is_dir:
             return
-        stack = list(direct_matched_path.iterdir)
+        stack = list(direct_matched_path.iterdir())
         while stack:
             current_path = stack.pop()
             path_matcher.reserve(
@@ -779,7 +780,7 @@ class InstallRule(DebputyDispatchableType):
                 is_exact_match=False,
             )
             if current_path.is_dir:
-                stack.extend(current_path.iterdir)
+                stack.extend(current_path.iterdir())
 
     def _install_dir_recursively(
         self,
@@ -790,7 +791,7 @@ class InstallRule(DebputyDispatchableType):
     ) -> None:
         stack = [
             (parent_dirs, e)
-            for e in match.path.iterdir
+            for e in match.path.iterdir()
             if not path_matcher.is_reserved(e)
         ]
 
@@ -809,7 +810,7 @@ class InstallRule(DebputyDispatchableType):
                 ]
                 stack.extend(
                     (new_dirs, de)
-                    for de in dir_entry.iterdir
+                    for de in dir_entry.iterdir()
                     if not path_matcher.is_reserved(de)
                 )
             elif dir_entry.is_symlink:
