@@ -53,7 +53,7 @@ def translation(
                 mo_dir = os.path.join(locale_dir, language, "LC_MESSAGES")
                 os.makedirs(mo_dir, exist_ok=True)
                 mo_path = os.path.join(mo_dir, f"{domain}.mo")
-                parsed_po_file = polib.pofile(child)
+                parsed_po_file = polib.pofile(str(child))
                 parsed_po_file.save_as_mofile(mo_path)
             _GENERATED_MO_FILES_FOR.add(domain)
         try:
