@@ -1,9 +1,8 @@
-import asyncio
 import re
 from email.utils import parsedate_to_datetime
 from typing import TYPE_CHECKING, Sequence, Optional
 
-from debputy.linting.lint_util import LintState
+from debputy.linting.lint_util import LintState, te_range_to_lsp
 from debputy.lsp.lsp_features import (
     lsp_standard_handler,
     SecondaryLanguage,
@@ -543,8 +542,14 @@ def _debian_changelog_links(
                 bug_span[0] + bug_offset,
                 bug_span[1] + bug_offset,
             )
+            bug_range_client_units = doc.position_codec.range_to_client_units(
+                lines,
+                te_range_to_lsp(bug_range),
+            )
             links.append(
-                types.DocumentLink(bug_range, f"https://bugs.debian.org/{bug_id}")
+                types.DocumentLink(
+                    bug_range_client_units, f"https://bugs.debian.org/{bug_id}"
+                )
             )
 
             total_links = len(links)
