@@ -3,17 +3,13 @@ from itertools import chain
 from typing import (
     Optional,
     Union,
-    Sequence,
     Tuple,
     Any,
-    Container,
     List,
-    Iterable,
-    Iterator,
-    Callable,
     cast,
     TYPE_CHECKING,
 )
+from collections.abc import Sequence, Container, Iterable, Iterator, Callable
 
 from debputy.linting.lint_util import (
     LintState,
@@ -122,7 +118,7 @@ def _field_at_position(
     stanza_metadata: S,
     stanza_range: TERange,
     position: Position,
-) -> Tuple[Optional[Deb822KeyValuePairElement], Optional[F], str, bool]:
+) -> tuple[Deb822KeyValuePairElement | None, F | None, str, bool]:
     te_range = TERange(stanza_range.start_pos, stanza_range.start_pos)
     for token_or_element in stanza.iter_parts():
         te_range = token_or_element.size().relative_to(te_range.end_pos)
@@ -173,16 +169,16 @@ def _at_cursor(
     deb822_file: Deb822FileElement,
     file_metadata: Deb822FileMetadata[S, F],
     doc: "TextDocument",
-    lines: List[str],
+    lines: list[str],
     client_position: Position,
     is_completion: bool = False,
-) -> Tuple[
+) -> tuple[
     Position,
-    Optional[str],
+    str | None,
     str,
     bool,
-    Optional[S],
-    Optional[F],
+    S | None,
+    F | None,
     Iterable[Deb822ParagraphElement],
 ]:
     server_position = doc.position_codec.position_from_client_units(
@@ -194,15 +190,15 @@ def _at_cursor(
         START_POSITION,
     )
     paragraph_no = -1
-    previous_stanza: Optional[Deb822ParagraphElement] = None
-    next_stanza: Optional[Deb822ParagraphElement] = None
+    previous_stanza: Deb822ParagraphElement | None = None
+    next_stanza: Deb822ParagraphElement | None = None
     current_word = doc.word_at_position(client_position)
     in_value: bool = False
     file_iter = iter(deb822_file.iter_parts())
-    matched_token: Optional[TokenOrElement] = None
-    matched_field: Optional[str] = None
-    stanza_metadata: Optional[S] = None
-    known_field: Optional[F] = None
+    matched_token: TokenOrElement | None = None
+    matched_field: str | None = None
+    stanza_metadata: S | None = None
+    known_field: F | None = None
 
     for token_or_element in file_iter:
         te_range = token_or_element.size().relative_to(te_range.end_pos)
@@ -258,16 +254,12 @@ def deb822_completer(
     ls: "DebputyLanguageServer",
     params: CompletionParams,
     file_metadata: Deb822FileMetadata[Any, Any],
-) -> Optional[Union[CompletionList, Sequence[CompletionItem]]]:
+) -> CompletionList | Sequence[CompletionItem] | None:
     doc = ls.workspace.get_text_document(params.text_document.uri)
     lines = doc.lines
     lint_state = ls.lint_state(doc)
     deb822_file = lint_state.parsed_deb822_file_content
-    if deb822_file is None:
-        _warn("The deb822 result missing failed!?")
-        ls.show_message_log(
-            "Internal error; could not get deb822 content!?", MessageType.Warning
-        )
+    if not file_metadata.file_metadata_applies_to_file(deb822_file):
         return None
 
     (
@@ -290,7 +282,7 @@ def deb822_completer(
     if lines[server_pos.line].startswith("#"):
         return
 
-    items: Optional[Sequence[CompletionItem]]
+    items: Sequence[CompletionItem] | None
     markdown_kind = ls.completion_item_document_markup(
         MarkupKind.Markdown, MarkupKind.PlainText
     )
@@ -323,32 +315,27 @@ def deb822_hover(
     params: HoverParams,
     file_metadata: Deb822FileMetadata[S, F],
     *,
-    custom_handler: Optional[
+    custom_handler: None | (
         Callable[
             [
                 "DebputyLanguageServer",
                 Position,
-                Optional[str],
+                str | None,
                 str,
-                Optional[F],
+                F | None,
                 bool,
                 "TextDocument",
-                List[str],
+                list[str],
             ],
-            Optional[Hover],
+            Hover | None,
         ]
-    ] = None,
-) -> Optional[Hover]:
+    ) = None,
+) -> Hover | None:
     doc = ls.workspace.get_text_document(params.text_document.uri)
-    lines = doc.lines
     deb822_file = ls.lint_state(doc).parsed_deb822_file_content
-    if deb822_file is None:
-        _warn("The deb822 result missing failed!?")
-        ls.show_message_log(
-            "Internal error; could not get deb822 content!?", MessageType.Warning
-        )
+    if not file_metadata.file_metadata_applies_to_file(deb822_file):
         return None
-
+    lines = doc.lines
     (
         server_pos,
         current_field,
@@ -366,7 +353,7 @@ def deb822_hover(
     )
 
     if lines[server_pos.line].startswith("#"):
-        return
+        return None
 
     hover_text = None
     if custom_handler is not None:
@@ -424,7 +411,7 @@ def deb822_hover(
 
 def deb822_token_iter(
     tokens: Iterable[Deb822Token],
-) -> Iterator[Tuple[Deb822Token, int, int, int, int]]:
+) -> Iterator[tuple[Deb822Token, int, int, int, int]]:
     line_no = 0
     line_offset = 0
 
@@ -450,10 +437,12 @@ def deb822_token_iter(
 def deb822_folding_ranges(
     ls: "DebputyLanguageServer",
     params: FoldingRangeParams,
-    # Unused for now: might be relevant for supporting folding for some fields
-    _file_metadata: Deb822FileMetadata[Any, Any],
-) -> Optional[Sequence[FoldingRange]]:
+    file_metadata: Deb822FileMetadata[Any, Any],
+) -> Sequence[FoldingRange] | None:
     doc = ls.workspace.get_text_document(params.text_document.uri)
+    deb822_file = ls.lint_state(doc).parsed_deb822_file_content
+    if not file_metadata.file_metadata_applies_to_file(deb822_file):
+        return None
     comment_start = -1
     folding_ranges = []
     for (
@@ -462,7 +451,7 @@ def deb822_folding_ranges(
         start_offset,
         end_line,
         end_offset,
-    ) in deb822_token_iter(tokenize_deb822_file(doc.lines)):
+    ) in deb822_token_iter(deb822_file.iter_tokens()):
         if token.is_comment:
             if comment_start < 0:
                 comment_start = start_line
@@ -497,8 +486,8 @@ class Deb822SemanticTokensState(SemanticTokensState):
         self,
         ls: "DebputyLanguageServer",
         doc: "TextDocument",
-        lines: List[str],
-        tokens: List[int],
+        lines: list[str],
+        tokens: list[int],
         file_metadata: Deb822FileMetadata[Any, Any],
     ) -> None:
         super().__init__(ls, doc, lines, tokens)
@@ -601,7 +590,7 @@ async def scan_for_syntax_errors_and_token_level_diagnostics(
 
 def _emit_relation_token(
     sem_token_state: Deb822SemanticTokensState,
-    token_code: Optional[int],
+    token_code: int | None,
     m: re.Match[str],
     group_name: str,
     value_range_te: TERange,
@@ -746,7 +735,7 @@ async def _deb822_paragraph_semantic_tokens_full(
             keyword_token_code,
         )
 
-        known_field: Optional[Deb822KnownField] = stanza_metadata.get(kvpair.field_name)
+        known_field: Deb822KnownField | None = stanza_metadata.get(kvpair.field_name)
         value_element_pos = kvpair.value_element.position_in_parent().relative_to(
             kvpair_position
         )
@@ -830,9 +819,9 @@ async def _deb822_paragraph_semantic_tokens_full(
 
 def _split_into_substvars(
     value: str,
-    base_token_type: Optional[int],
+    base_token_type: int | None,
     substvar_token_type: int,
-) -> Iterable[Tuple[str, Optional[int]]]:
+) -> Iterable[tuple[str, int | None]]:
 
     i = 0
     next_search = i
@@ -850,9 +839,6 @@ def _split_into_substvars(
         subst_var_end += 1
         subst_var = value[subst_var_start:subst_var_end]
         if subst_var != "${}" and not SUBSTVAR_RE.match(subst_var):
-            subst_var = None
-
-        if subst_var is None:
             next_search = subst_var_end
             continue
 
@@ -868,7 +854,7 @@ def _process_value_with_substvars(
     sem_token_state: Deb822SemanticTokensState,
     value: str,
     value_range_te: "TERange",
-    base_token_type: Optional[int],
+    base_token_type: int | None,
 ) -> None:
     pos_codec = sem_token_state.doc.position_codec
 
@@ -895,7 +881,10 @@ def _process_value_with_substvars(
 def deb822_format_file(
     lint_state: LintState,
     file_metadata: Deb822FileMetadata[Any, Any],
-) -> Optional[Sequence[TextEdit]]:
+) -> Sequence[TextEdit] | None:
+    deb822_file = lint_state.parsed_deb822_file_content
+    if not file_metadata.file_metadata_applies_to_file(deb822_file):
+        return None
     effective_preference = lint_state.effective_preference
     if effective_preference is None:
         return trim_end_of_line_whitespace(lint_state.position_codec, lint_state.lines)
@@ -922,11 +911,13 @@ async def deb822_semantic_tokens_full(
     ls: "DebputyLanguageServer",
     request: SemanticTokensParams,
     file_metadata: Deb822FileMetadata[Any, Any],
-) -> Optional[SemanticTokens]:
+) -> SemanticTokens | None:
     doc = ls.workspace.get_text_document(request.text_document.uri)
+    deb822_file = ls.lint_state(doc).parsed_deb822_file_content
+    if not file_metadata.file_metadata_applies_to_file(deb822_file):
+        return None
     position_codec = doc.position_codec
     lines = doc.lines
-    deb822_file = ls.lint_state(doc).parsed_deb822_file_content
     if deb822_file is None:
         _warn("The deb822 result missing failed!?")
         ls.show_message_log(
@@ -934,7 +925,7 @@ async def deb822_semantic_tokens_full(
         )
         return None
 
-    tokens: List[int] = []
+    tokens: list[int] = []
     sem_token_state = Deb822SemanticTokensState(
         ls,
         doc,
@@ -980,7 +971,7 @@ def _complete_field_name(
 ) -> Sequence[CompletionItem]:
     items = []
     matched_stanzas = list(matched_stanzas)
-    seen_fields = set(
+    seen_fields = {
         stanza_metadata.normalize_field_name(f.lower())
         for f in chain.from_iterable(
             # The typing from python3-debian is not entirely optimal here. The iter always return a
@@ -991,7 +982,7 @@ def _complete_field_name(
             cast("Iterable[str]", s)
             for s in matched_stanzas
         )
-    )
+    }
     for cand_key, cand in stanza_metadata.items():
         if stanza_metadata.normalize_field_name(cand_key.lower()) in seen_fields:
             continue
