@@ -12,7 +12,7 @@ from typing import (
     Generic,
     cast,
 )
-from collections.abc import Iterable, Callable, Sequence
+from collections.abc import Iterable, Callable, Sequence, Iterator
 
 from debputy.commands.debputy_cmd.output import OutputStyle
 from debputy.linting.lint_util import LintState
@@ -848,7 +848,7 @@ def insert_complete_marker_snippet(
 
 def _keywords_with_parser(
     parser: DeclarativeMappingInputParser | DispatchingParserBase,
-) -> tuple[str, PluginProvidedParser]:
+) -> Iterator[tuple[str, PluginProvidedParser]]:
     for keyword in parser.registered_keywords():
         pp_subparser = parser.parser_for(keyword)
         yield keyword, pp_subparser
