@@ -151,7 +151,7 @@ class Keyword:
         )
 
 
-def allowed_values(*values: str | Keyword) -> Mapping[str, Keyword]:
+def allowed_values(values: Iterable[str | Keyword]) -> Mapping[str, Keyword]:
     as_keywords = [k if isinstance(k, Keyword) else Keyword(k) for k in values]
     as_mapping = {k.value: k for k in as_keywords if k.value}
     # Simple bug check
@@ -163,5 +163,5 @@ def allowed_values(*values: str | Keyword) -> Mapping[str, Keyword]:
 # the ones in the config file.
 ALL_PUBLIC_NAMED_STYLES_AS_KEYWORDS = allowed_values(
     Keyword(s.name, long_description=s.long_description)
-    for s in ALL_PUBLIC_NAMED_STYLES
+    for s in ALL_PUBLIC_NAMED_STYLES.values()
 )
