@@ -1,15 +1,8 @@
 import itertools
 from string import Template
-from typing import (
-    Optional,
-    Any,
-    Tuple,
-    FrozenSet,
-    Union,
-)
+from typing import Any, Union
 from collections.abc import Iterable, Mapping, Sequence, Container
 
-from debputy import DEBPUTY_DOC_ROOT_DIR
 from debputy.commands.debputy_cmd.output import OutputStyle
 from debputy.manifest_parser.declarative_parser import (
     DeclarativeMappingInputParser,
@@ -37,6 +30,7 @@ from debputy.plugin.api.spec import (
     TypeMappingExample,
 )
 from debputy.util import assume_not_none, _error, _warn
+from debputy.version import debputy_doc_root_dir
 
 
 def _provide_placeholder_parser_doc(
@@ -67,7 +61,7 @@ def doc_args_for_parser_doc(
     else:
         attributes = []
     if manifest_format_url is None:
-        manifest_format_url = f"{DEBPUTY_DOC_ROOT_DIR}/MANIFEST-FORMAT.md"
+        manifest_format_url = f"{debputy_doc_root_dir()}/MANIFEST-FORMAT.md"
     doc_args = {
         "RULE_NAME": rule_name,
         "MANIFEST_FORMAT_DOC": manifest_format_url,
