@@ -25,7 +25,7 @@ _GLOB_PARTS = re.compile(r"[*?]|\[]?[^]]+]")
 def _lookup_path(fs_root: VP, path: str) -> VP | None:
     if not path.startswith("./"):
         raise ValueError("Directory must be normalized (and not the root directory)")
-    if fs_root.name != "." or fs_root.parent_dir is not None:
+    if not fs_root.is_root_dir():
         raise ValueError("Provided fs_root must be the root directory")
     # TODO: Strictly speaking, this is unsound. (E.g., FSRootDir does not return FSRootDir on a lookup)
     return fs_root.lookup(path[2:])
@@ -67,7 +67,7 @@ def _apply_match(
         if m:
             yield m
     else:
-        yield from (p for p in fs_path.iterdir if match_part(p.name))
+        yield from (p for p in fs_path.iterdir() if match_part(p.name))
 
 
 class MatchRuleType(Enum):
@@ -304,7 +304,7 @@ class DirectoryBasedMatch(MatchRule):
         if self._rule_type == MatchRuleType.ANYTHING_BENEATH_DIR:
             path_iter = p.all_paths()
         else:
-            path_iter = p.iterdir
+            path_iter = p.iterdir()
         if ignore_paths is not None:
             path_iter = (p for p in path_iter if not ignore_paths(p))
         if self._path_type is None:
@@ -391,7 +391,7 @@ class BasenameGlobMatch(MatchRule):
                 return
             search_root = p
         path_iter = (
-            search_root.all_paths() if self._recursive_match else search_root.iterdir
+            search_root.all_paths() if self._recursive_match else search_root.iterdir()
         )
         if ignore_paths is not None:
             path_iter = (p for p in path_iter if not ignore_paths(p))
