@@ -600,7 +600,7 @@ class InitializedPluginUnderTestImpl(InitializedPluginUnderTest):
         fs_root: VirtualPath,
         context: PackageProcessingContext | None = None,
     ) -> RegisteredMetadata:
-        if fs_root.parent_dir is not None:
+        if not fs_root.is_root_dir():
             raise ValueError("Provided path must be the file system root.")
         detectors = self._feature_set.metadata_maintscript_detectors[self._plugin_name]
         matching_detectors = [
@@ -643,7 +643,7 @@ class InitializedPluginUnderTestImpl(InitializedPluginUnderTest):
         fs_root: VirtualPath,
         context: PackageProcessingContext | None = None,
     ) -> None:
-        if fs_root.parent_dir is not None:
+        if not fs_root.is_root_dir():
             raise ValueError("Provided path must be the file system root.")
         pp_key = (self._plugin_name, package_processor_id)
         package_processor = self._feature_set.all_package_processors.get(pp_key)
@@ -713,7 +713,7 @@ class InitializedPluginUnderTestImpl(InitializedPluginUnderTest):
         *,
         service_context_type_hint: type[DSD] | None = None,
     ) -> tuple[list[DetectedService[DSD]], RegisteredMetadata]:
-        if fs_root.parent_dir is not None:
+        if not fs_root.is_root_dir():
             raise ValueError("Provided path must be the file system root.")
         try:
             service_manager_details = self._feature_set.service_managers[
