@@ -1,3 +1,4 @@
+import collections
 import dataclasses
 import json
 import os
@@ -8,11 +9,7 @@ from typing import (
     TypedDict,
     Self,
     cast,
-    Dict,
-    List,
-    Tuple,
     Union,
-    Optional,
     TYPE_CHECKING,
     Literal,
     Required,
@@ -204,7 +201,7 @@ def register_build_keywords(api: DebputyPluginInitializerProvider) -> None:
 
                 The environment definition can be used to tweak the environment variables used by the
                 build commands. An example:
-                
+
                     default-build-environment:
                       set:
                         ENV_VAR: foo
@@ -213,7 +210,7 @@ def register_build_keywords(api: DebputyPluginInitializerProvider) -> None:
                 The environment definition has multiple attributes for setting environment variables
                 which determines when the definition is applied. The resulting environment is the
                 result of the following order of operations.
-                
+
                   1. The environment `debputy` received from its parent process.
                   2. Apply all the variable definitions from `set` (if the attribute is present)
                   3. Apply all computed variables (such as variables from `dpkg-buildflags`).
@@ -460,10 +457,7 @@ def _no_overlap(
     attribute_path: AttributePath,
 ) -> None:
     for kt in lhs:
-        if isinstance(kt, tuple):
-            lhs_path_key, var = kt
-        else:
-            lhs_path_key = var = kt
+        lhs_path_key, var = kt if isinstance(kt, tuple) else (kt, kt)
         if var not in rhs:
             continue
         lhs_path = attribute_path[lhs_key][lhs_path_key].path_key_lc
@@ -606,10 +600,7 @@ class MakefileBuildSystemRule(StepBasedBuildSystemRule):
     ) -> None:
         super().__init__(attributes, attribute_path, parser_context)
         directory = attributes.get("directory")
-        if directory is not None:
-            self._directory = directory.match_rule.path
-        else:
-            self._directory = None
+        self._directory = directory.match_rule.path if directory else None
         self._make_support = MakefileSupport.from_build_system(self)
         self._build_target = attributes.get("build_target")
         self._test_target = attributes.get("test_target")
@@ -1059,10 +1050,9 @@ class DebhelperBuildSystemRule(StepBasedBuildSystemRule):
             )
         except subprocess.CalledProcessError:
             return False
-        else:
-            d = json.loads(v)
-            build_system = d.get("build-system")
-            return build_system is not None and build_system != "none"
+        d = json.loads(v)
+        build_system = d.get("build-system")
+        return build_system is not None and build_system != "none"
 
     @classmethod
     def characteristics(cls) -> BuildSystemCharacteristics:
@@ -1181,8 +1171,7 @@ class AutoconfBuildSystemRule(StepBasedBuildSystemRule):
         parser_context: Union[ParserContextData, "HighLevelManifest"],
     ) -> None:
         super().__init__(parsed_data, attribute_path, parser_context)
-        configure_args = [a for a in parsed_data.get("configure_args", [])]
-        self.configure_args = configure_args
+        self.configure_args = list(parsed_data.get("configure_args", []))
         self._make_support = MakefileSupport.from_build_system(self)
 
     @classmethod
@@ -1351,8 +1340,7 @@ class CMakeBuildSystemRule(StepBasedBuildSystemRule):
         parser_context: Union[ParserContextData, "HighLevelManifest"],
     ) -> None:
         super().__init__(parsed_data, attribute_path, parser_context)
-        configure_args = [a for a in parsed_data.get("configure_args", [])]
-        self.configure_args = configure_args
+        self.configure_args = list(parsed_data.get("configure_args", []))
         self.target_build_system: Literal["make", "ninja"] = parsed_data.get(
             "target_build_system", "make"
         )
@@ -1630,8 +1618,7 @@ class MesonBuildSystemRule(StepBasedBuildSystemRule):
         parser_context: Union[ParserContextData, "HighLevelManifest"],
     ) -> None:
         super().__init__(parsed_data, attribute_path, parser_context)
-        configure_args = [a for a in parsed_data.get("configure_args", [])]
-        self.configure_args = configure_args
+        self.configure_args = list(parsed_data.get("configure_args", []))
         self._ninja_support = NinjaBuildSupport.from_build_system(self)
 
     @classmethod
@@ -1684,12 +1671,6 @@ class MesonBuildSystemRule(StepBasedBuildSystemRule):
         host_arch = context.dpkg_architecture_variables.current_host_arch
         cross_file = os.path.join(cross_files_dir, f"meson-cross-file-{host_arch}.conf")
         if not os.path.isfile(cross_file):
-            env = os.environ
-            if env.get("LC_ALL") != "C.UTF-8":
-                env = dict(env)
-                env["LC_ALL"] = "C.UTF-8"
-            else:
-                env = None
             subprocess.check_call(
                 [
                     "/usr/share/meson/debcrossgen",
@@ -1697,7 +1678,7 @@ class MesonBuildSystemRule(StepBasedBuildSystemRule):
                     f"-o{cross_file}",
                 ],
                 stdout=subprocess.DEVNULL,
-                env=env,
+                env=collections.ChainMap({"LC_ALL": "C.UTF-8"}, os.environ),
             )
 
         meson_flags.append("--cross-file")
@@ -1849,8 +1830,7 @@ class AbstractQmakeBuildSystemRule(StepBasedBuildSystemRule):
         parser_context: Union[ParserContextData, "HighLevelManifest"],
     ) -> None:
         super().__init__(parsed_data, attribute_path, parser_context)
-        configure_args = [a for a in parsed_data.get("configure_args", [])]
-        self.configure_args = configure_args
+        self.configure_args = list(parsed_data.get("configure_args", []))
         self._make_support = MakefileSupport.from_build_system(self)
 
     @classmethod
@@ -1866,7 +1846,7 @@ class AbstractQmakeBuildSystemRule(StepBasedBuildSystemRule):
         *args,
         **kwargs,
     ) -> bool:
-        return any(p.name.endswith(".pro") for p in source_root.iterdir)
+        return any(p.name.endswith(".pro") for p in source_root.iterdir())
 
     @classmethod
     def os_mkspec_mapping(cls) -> Mapping[str, str]:
