@@ -47,7 +47,7 @@ def detect_initramfs_hooks(
     hook_dir = fs_root.lookup(INITRAMFS_HOOK_DIR)
     if not hook_dir:
         return
-    for _ in hook_dir.iterdir:
+    for _ in hook_dir.iterdir():
         # Only add the trigger if the directory is non-empty. It is unlikely to matter a lot,
         # but we do this to match debhelper.
         break
@@ -67,7 +67,7 @@ def _all_tmpfiles_conf(fs_root: VirtualPath) -> Iterable[VirtualPath]:
         tmpfiles_dir = fs_root.lookup(tmpfiles_dir_path)
         if not tmpfiles_dir:
             continue
-        for path in tmpfiles_dir.iterdir:
+        for path in tmpfiles_dir.iterdir():
             if (
                 not path.is_file
                 or not path.name.endswith(".conf")
@@ -106,7 +106,7 @@ def _all_sysusers_conf(fs_root: VirtualPath) -> Iterable[VirtualPath]:
     sysusers_dir = fs_root.lookup(SYSTEMD_SYSUSERS_DIR)
     if not sysusers_dir:
         return
-    for child in sysusers_dir.iterdir:
+    for child in sysusers_dir.iterdir():
         if not child.name.endswith(".conf"):
             continue
         yield child
@@ -146,7 +146,7 @@ def detect_commands(
         path_dir = fs_root.lookup(path_name)
         if path_dir is None or not path_dir.is_dir:
             continue
-        for child in path_dir.iterdir:
+        for child in path_dir.iterdir():
             if not (child.is_file or child.is_symlink):
                 continue
             ctrl.substvars.add_dependency("misc:Commands", child.name)
@@ -161,7 +161,7 @@ def detect_icons(
     if not icons_root_dir:
         return
     icon_dirs = []
-    for subdir in icons_root_dir.iterdir:
+    for subdir in icons_root_dir.iterdir():
         if subdir.name in ("gnome", "hicolor"):
             # dh_icons skips this for some reason.
             continue
@@ -224,7 +224,7 @@ def detect_kernel_modules(
 
         module_version_dirs = []
 
-        for module_version_dir in module_root_dir.iterdir:
+        for module_version_dir in module_root_dir.iterdir():
             if not module_version_dir.is_dir:
                 continue
 
@@ -272,7 +272,7 @@ def detect_xfonts(
     escape_shell_words = ctrl.maintscript.escape_shell_words
     package_name = context.binary_package.name
 
-    for xfonts_dir in xfonts_root_dir.iterdir:
+    for xfonts_dir in xfonts_root_dir.iterdir():
         xfonts_dirname = xfonts_dir.name
         if not xfonts_dir.is_dir or xfonts_dirname.startswith("."):
             continue
@@ -343,7 +343,7 @@ def _public_python_dist_dirs(fs_root: VirtualPath) -> Iterator[VirtualPath]:
     for root_dir in root_dirs:
         python_dirs = (
             path
-            for path in root_dir.iterdir
+            for path in root_dir.iterdir()
             if path.is_dir and _PYTHON_PUBLIC_DIST_DIR_NAMES.match(path.name)
         )
         for python_dir in python_dirs:
@@ -500,7 +500,7 @@ def pam_auth_update(
     if not pam_configs:
         return
     maintscript = ctrl.maintscript
-    for pam_config in pam_configs.iterdir:
+    for pam_config in pam_configs.iterdir():
         if not pam_config.is_file:
             continue
         maintscript.on_configure("pam-auth-update --package\n")
@@ -533,7 +533,7 @@ def auto_depends_arch_any_solink(
         libdirs = [libbasedir]
     targets = []
     for libdir in libdirs:
-        for path in libdir.iterdir:
+        for path in libdir.iterdir():
             if not path.is_symlink or not path.name.endswith(".so"):
                 continue
             target = path.readlink()
