@@ -318,7 +318,7 @@ def _la_files(fs_root: VirtualPath) -> Iterator[VirtualPath]:
     # Original code only iterators directly in /usr/lib. To be a faithful conversion, we do the same
     # here.
     # Eagerly resolve the list as the replacement can trigger a runtime error otherwise
-    paths = list(lib_dir.iterdir)
+    paths = list(lib_dir.iterdir())
     yield from (p for p in paths if p.is_file and p.name.endswith(".la"))
 
 
