@@ -247,7 +247,7 @@ def _find_and_analyze_systemd_service_files(
         system_dir = fs_root.lookup(d)
         if not system_dir:
             continue
-        for child in system_dir.iterdir:
+        for child in system_dir.iterdir():
             if child.is_symlink:
                 dest = os.path.basename(child.readlink())
                 aliases[dest].append(child.name)
@@ -441,7 +441,7 @@ def detect_sysv_init_service_files(
     etc_init = fs_root.lookup("/etc/init.d")
     if not etc_init:
         return
-    for path in etc_init.iterdir:
+    for path in etc_init.iterdir():
         if path.is_dir or not path.is_executable:
             continue
 
