@@ -1,4 +1,5 @@
 import dataclasses
+import typing
 from collections.abc import Sequence
 
 from debian.deb822 import PkgRelation
@@ -15,32 +16,20 @@ class DebputyCapability:
     definition_source: str
 
 
-@dataclasses.dataclass(slots=True)
-class MatchedBuiltUsingRelation:
-    name: str
+class MatchedBuiltUsingRelation(typing.NamedTuple):
     is_first: bool
     relationship: "PkgRelation.ParsedRelation"
 
 
-@dataclasses.dataclass(slots=True)
-class BuiltUsingBase:
-    sources_for: str
+class BuiltUsingItem(typing.NamedTuple):
     matched_packages: Sequence[MatchedBuiltUsingRelation]
     conditional: ManifestCondition | None
     attribute_path: AttributePath
 
-    @classmethod
-    def field_name(cls) -> str:
-        raise NotImplementedError
+
+class StaticBuiltUsing(tuple[BuiltUsingItem, ...]):
+    pass
 
 
-class StaticBuiltUsing(BuiltUsingBase):
-    @classmethod
-    def field_name(cls) -> str:
-        return "Static-Built-Using"
-
-
-class BuiltUsing(BuiltUsingBase):
-    @classmethod
-    def field_name(cls) -> str:
-        return "Built-Using"
+class BuiltUsing(tuple[BuiltUsingItem, ...]):
+    pass
