@@ -332,7 +332,7 @@ class CreateSymlinkPathTransformationRule(TransformationRule):
     def _handle_existing_path(self, existing: VirtualPath) -> None:
         replacement_rule = self._replacement_rule
         if replacement_rule == "abort-on-non-empty-directory":
-            unlink = not existing.is_dir or not any(existing.iterdir)
+            unlink = not existing.is_dir or not any(existing.iterdir())
             reason = "the path is a non-empty directory"
         elif replacement_rule == "discard-existing":
             unlink = True
