@@ -1,5 +1,6 @@
 import textwrap
-from typing import List, Optional
+import typing
+from typing import TYPE_CHECKING
 
 import pytest
 
@@ -7,8 +8,8 @@ from debputy.filesystem_scan import build_virtual_fs
 from debputy.lsp.config.config_options import DCO_SPELLCHECK_COMMENTS
 from debputy.lsp.languages.lsp_debian_control import _lint_debian_control
 from debputy.lsp.lsp_debian_control_reference_data import CURRENT_STANDARDS_VERSION
+from debputy.lsp.maint_prefs import MaintainerPreferenceTable
 from debputy.lsp.vendoring._deb822_repro import parse_deb822_file
-from debputy.lsprotocol.types import Diagnostic, DiagnosticSeverity
 from debputy.packages import DctrlParser
 from debputy.plugin.api import virtual_path_def
 from debputy.plugin.api.feature_set import PluginProvidedFeatureSet
@@ -17,9 +18,22 @@ from lint_tests.lint_tutil import (
     requires_levenshtein,
     LintWrapper,
     diag_range_to_text,
+    apply_code_action_edits,
+    standard_quick_fixes_for_diagnostic,
+    code_actions_for,
 )
 from tutil import build_time_only, with_plugins_loaded
 
+
+if TYPE_CHECKING:
+    from lsprotocol import types
+else:
+    from debputy.lsprotocol import types
+
+
+DiagnosticSeverity = types.DiagnosticSeverity
+
+
 ALL_REQUIRED_FILES = [
     "debian/changelog",
     "debian/copyright",
@@ -28,7 +42,7 @@ ALL_REQUIRED_FILES = [
 
 class DctrlLintWrapper(LintWrapper):
 
-    def __call__(self, lines: List[str]) -> Optional[List["Diagnostic"]]:
+    def __call__(self, lines: list[str]) -> list[types.Diagnostic]:
         try:
             self.dctrl_lines = lines
             return super().__call__(lines)
@@ -75,9 +89,9 @@ def test_dctrl_lint(line_linter: LintWrapper) -> None:
 
     errors = by_severity[DiagnosticSeverity.Error]
     print(errors)
-    assert len(errors) == 3
+    assert len(errors) == 2
 
-    first_error, second_error, third_error = errors
+    first_error, second_error = errors
 
     msg = "Stanza is missing field Standards-Version"
     assert first_error.message == msg
@@ -87,10 +101,6 @@ def test_dctrl_lint(line_linter: LintWrapper) -> None:
     assert second_error.message == msg
     assert f"{second_error.range}" == "0:0-1:0"
 
-    msg = "Stanza is missing field Priority"
-    assert third_error.message == msg
-    assert f"{third_error.range}" == "5:0-6:0"
-
     warnings = by_severity[DiagnosticSeverity.Warning]
     assert len(warnings) == 2
 
@@ -1610,7 +1620,7 @@ def test_dctrl_duplicate_key(line_linter: LintWrapper) -> None:
 
     issue = diagnostics[0]
 
-    msg = "The Multi-Arch field name was used multiple times in this stanza. Please ensure the field is only used once per stanza."
+    msg = 'The field "Multi-Arch" was used multiple times in this stanza. Please ensure the field is only used once per stanza.'
     assert issue.message == msg
     assert f"{issue.range}" == "27:0-27:10"
     assert issue.severity == DiagnosticSeverity.Error
@@ -1959,8 +1969,10 @@ def test_spellcheck_ignore_package_names(
     assert issue.message == msg
     assert f"{issue.range}" == f"16:10-16:17"
     assert issue.severity == DiagnosticSeverity.Hint
-    assert "enable_non_interactive_auto_fix" in issue.data
-    assert not issue.data["enable_non_interactive_auto_fix"]
+    issue_data: dict[str, typing.Any] | None = issue.data
+    assert issue_data is not None
+    assert "enable_non_interactive_auto_fix" in issue_data
+    assert not issue_data["enable_non_interactive_auto_fix"]
 
     lines = textwrap.dedent(
         f"""\
@@ -2203,3 +2215,207 @@ def test_config_spell_checking_comments(
     diagnostics = line_linter(lines)
     print(diagnostics)
     assert not diagnostics
+
+
+def test_dctrl_lint_x_doc_main_package_single_binary(line_linter: LintWrapper) -> None:
+    lines = textwrap.dedent(
+        f"""\
+    Source: foo
+    Standards-Version: {CURRENT_STANDARDS_VERSION}
+    Build-Depends: debhelper-compat (= 13)
+    Maintainer: Jane Developer <jane@example.com>
+    Homepage: https://example.com
+
+    Package: foo
+    Architecture: all
+    Section: misc
+    X-Doc-Main-Package: foo
+    Description: some short synopsis
+     A very interesting description
+     with a valid synopsis
+     .
+     Just so be clear, this is for a test.
+    """
+    ).splitlines(keepends=True)
+
+    diagnostics = line_linter(lines)
+    print(diagnostics)
+    assert diagnostics and len(diagnostics) == 1
+    issue = diagnostics[0]
+
+    msg = "The X-Doc-Main-Package field is redundant for source packages that only build one binary package"
+    assert issue.message == msg
+    assert f"{issue.range}" == "9:0-10:0"
+    assert issue.severity == DiagnosticSeverity.Warning
+    assert diag_range_to_text(lines, issue.range) == "X-Doc-Main-Package: foo\n"
+
+
+def test_dctrl_lint_x_doc_main_package_unknown_package(
+    line_linter: LintWrapper,
+) -> None:
+    lines = textwrap.dedent(
+        f"""\
+    Source: foo
+    Standards-Version: {CURRENT_STANDARDS_VERSION}
+    Build-Depends: debhelper-compat (= 13)
+    Maintainer: Jane Developer <jane@example.com>
+    Homepage: https://example.com
+
+    Package: foo
+    Architecture: all
+    Section: misc
+    Description: some short synopsis
+     A very interesting description
+     with a valid synopsis
+     .
+     Just so be clear, this is for a test.
+
+    Package: foo-doc
+    Architecture: all
+    Section: doc
+    X-Doc-Main-Package: fubar
+    Description: some short synopsis
+     A very interesting description
+     with a valid synopsis
+     .
+     Just so be clear, this is for a test.
+    """
+    ).splitlines(keepends=True)
+
+    diagnostics = line_linter(lines)
+    print(diagnostics)
+    assert diagnostics and len(diagnostics) == 1
+    issue = diagnostics[0]
+
+    msg = "The X-Doc-Main-Package field must name a package listed in debian/control"
+    assert issue.message == msg
+    assert f"{issue.range}" == "18:20-18:25"
+    assert issue.severity == DiagnosticSeverity.Error
+    assert diag_range_to_text(lines, issue.range) == "fubar"
+
+
+def test_dctrl_lint_x_doc_main_package_valid(
+    line_linter: LintWrapper,
+) -> None:
+    lines = textwrap.dedent(
+        f"""\
+    Source: foo
+    Standards-Version: {CURRENT_STANDARDS_VERSION}
+    Build-Depends: debhelper-compat (= 13)
+    Maintainer: Jane Developer <jane@example.com>
+    Homepage: https://example.com
+
+    Package: foo-base
+    Architecture: all
+    Section: misc
+    X-Doc-Main-Package: foo
+    Description: some short synopsis
+     A very interesting description
+     with a valid synopsis
+     .
+     Just so be clear, this is for a test.
+
+    Package: foo
+    Architecture: all
+    Section: misc
+    Description: some short synopsis
+     A very interesting description
+     with a valid synopsis
+     .
+     Just so be clear, this is for a test.
+    """
+    ).splitlines(keepends=True)
+
+    diagnostics = line_linter(lines)
+    print(diagnostics)
+    assert not diagnostics
+
+
+def test_dctrl_lint_maintainer_canonical_name(
+    line_linter: LintWrapper,
+) -> None:
+    styles = MaintainerPreferenceTable.load_preferences()
+    line_linter.maint_preference_table = styles
+    lines = textwrap.dedent(
+        f"""\
+    Source: foo
+    Standards-Version: {CURRENT_STANDARDS_VERSION}
+    Build-Depends: debhelper-compat (= 13)
+    Maintainer: Jane Developer <jane@example.com>
+    Uploaders: NT <niels@thykier.net>
+    Homepage: https://example.com
+
+    Package: foo-base
+    Architecture: all
+    Section: misc
+    X-Doc-Main-Package: foo
+    Description: some short synopsis
+     A very interesting description
+     with a valid synopsis
+     .
+     Just so be clear, this is for a test.
+
+    Package: foo
+    Architecture: all
+    Section: misc
+    Description: some short synopsis
+     A very interesting description
+     with a valid synopsis
+     .
+     Just so be clear, this is for a test.
+    """
+    ).splitlines(keepends=True)
+
+    diagnostics = line_linter(lines)
+    print(diagnostics)
+    assert len(diagnostics) == 1
+    issue = diagnostics[0]
+
+    msg = "Non-canonical or incorrect spelling of maintainer name"
+    assert issue.message == msg
+    assert f"{issue.range}" == "4:11-4:33"
+    assert issue.severity == DiagnosticSeverity.Information
+    assert diag_range_to_text(lines, issue.range) == "NT <niels@thykier.net>"
+    quick_fixes = standard_quick_fixes_for_diagnostic(
+        line_linter.lint_state,
+        code_actions_for(line_linter.lint_state.doc_uri, issue.range),
+        issue,
+    )
+    assert len(quick_fixes) == 1
+    quick_fix = quick_fixes[0]
+    assert isinstance(quick_fix, types.CodeAction)
+    fixed_text = apply_code_action_edits(
+        line_linter.lint_state.doc_uri,
+        lines,
+        quick_fix,
+    )
+
+    expected_text = textwrap.dedent(
+        f"""\
+    Source: foo
+    Standards-Version: {CURRENT_STANDARDS_VERSION}
+    Build-Depends: debhelper-compat (= 13)
+    Maintainer: Jane Developer <jane@example.com>
+    Uploaders: Niels Thykier <niels@thykier.net>
+    Homepage: https://example.com
+
+    Package: foo-base
+    Architecture: all
+    Section: misc
+    X-Doc-Main-Package: foo
+    Description: some short synopsis
+     A very interesting description
+     with a valid synopsis
+     .
+     Just so be clear, this is for a test.
+
+    Package: foo
+    Architecture: all
+    Section: misc
+    Description: some short synopsis
+     A very interesting description
+     with a valid synopsis
+     .
+     Just so be clear, this is for a test.
+    """
+    )
