@@ -4,6 +4,10 @@ from typing import Optional
 import pytest
 
 from debputy.lsp.debputy_ls import DebputyLanguageServer
+from debputy.lsp.lsp_test_support import (
+    resolved_semantic_token,
+    resolve_semantic_tokens,
+)
 from debputy.lsprotocol.types import (
     CompletionParams,
     TextDocumentIdentifier,
@@ -13,7 +17,7 @@ from debputy.lsprotocol.types import (
 )
 
 try:
-    from debputy.lsp.lsp_debian_control import (
+    from debputy.lsp.languages.lsp_debian_control import (
         _debian_control_completions,
         _debian_control_hover,
         _debian_control_semantic_tokens_full,
@@ -25,8 +29,6 @@ except ImportError:
 from lsp_tests.lsp_tutil import (
     put_doc_with_cursor,
     put_doc_no_cursor,
-    resolve_semantic_tokens,
-    resolved_semantic_token,
 )
 
 
@@ -134,7 +136,7 @@ def test_dctrl_complete_field(ls: "DebputyLanguageServer") -> None:
 def test_dctrl_complete_field_context(
     ls: "DebputyLanguageServer",
     case: str,
-    is_arch_all: Optional[bool],
+    is_arch_all: bool | None,
 ) -> None:
     dctrl_uri = "file:///nowhere/debian/control"
 
@@ -316,7 +318,7 @@ def test_dctrl_hover_doc_substvars(ls: "DebputyLanguageServer") -> None:
 
             Package: foo
             Architecture: any
-            Depends: bar (= {variant})
+            Depends: {variant}
             Description: super charged tool with batteries included
     """
             ),
@@ -344,7 +346,7 @@ def test_dctrl_hover_doc_substvars(ls: "DebputyLanguageServer") -> None:
 
             Package: foo
             Architecture: any
-            Depends: bar (= {variant})
+            Depends: {variant}
             Description: super charged tool with batteries included
     """
             ),
@@ -400,7 +402,6 @@ async def test_dctrl_semantic_tokens(ls: "DebputyLanguageServer") -> None:
         SemanticTokensParams(TextDocumentIdentifier(dctrl_uri)),
     )
     resolved_semantic_tokens = resolve_semantic_tokens(lines, semantic_tokens)
-    assert resolved_semantic_tokens is not None
     print(semantic_tokens)
     assert resolved_semantic_tokens == [
         resolved_semantic_token(0, 0, "# Some leading comment", "comment"),
@@ -412,6 +413,29 @@ async def test_dctrl_semantic_tokens(ls: "DebputyLanguageServer") -> None:
         resolved_semantic_token(8, len("Architecture: "), "any", "enumMember"),
         resolved_semantic_token(9, 0, "Depends", "keyword"),
         resolved_semantic_token(10, 0, "# Comment about bar", "comment"),
+        resolved_semantic_token(11, len("     "), "bar", "variable"),
+        resolved_semantic_token(11, len("     bar ("), ">=", "operator"),
+        # resolved_semantic_token(11, len("     bar (>= "), "1.0", "..."),
+        resolved_semantic_token(12, len("     "), "baz", "variable"),
+        resolved_semantic_token(12, len("     baz ["), "linux-any", "typeParameter"),
+        resolved_semantic_token(
+            12,
+            len("     baz [linux-any] <"),
+            "!pkg.foo.bootstrap",
+            "typeParameter",
+        ),
+        resolved_semantic_token(
+            13,
+            len("     "),
+            "libfoo",
+            "variable",
+        ),
+        resolved_semantic_token(
+            13,
+            len("     libfoo ("),
+            "=",
+            "operator",
+        ),
         resolved_semantic_token(
             13,
             len("     libfoo (= "),
