@@ -1,6 +1,6 @@
 import dataclasses
 import textwrap
-from typing import Dict, Self
+from typing import Self
 from collections.abc import Mapping
 
 import pytest
@@ -222,7 +222,7 @@ def test_install_rules(manifest_parser_pkg_foo) -> None:
     assert tool.is_symlink
     assert tool.readlink() == "./foo"
 
-    assert {"foo", "foo-util", "tool"} == {p.name for p in ub_dir.iterdir}
+    assert {"foo", "foo-util", "tool"} == {p.name for p in ub_dir.iterdir()}
     for n in ["foo", "foo-util"]:
         assert ub_dir[n].mtime == 10
     usf_dir = foo_fs_root.lookup("/usr/share/foo")
@@ -231,7 +231,7 @@ def test_install_rules(manifest_parser_pkg_foo) -> None:
     # Here we are installing an actual directory, so it should be present too
     assert usf_dir.has_fs_path
     assert usf_dir.fs_path == "/nowhere/debian/tmp/usr/share/foo"
-    assert {"foo.txt"} == {p.name for p in usf_dir.iterdir}
+    assert {"foo.txt"} == {p.name for p in usf_dir.iterdir()}
 
 
 def test_multi_dest_install_rules(manifest_parser_pkg_foo) -> None:
@@ -308,7 +308,7 @@ def test_multi_dest_install_rules(manifest_parser_pkg_foo) -> None:
         assert foo_dir.is_dir
 
         assert {"foo-a.data", "foo-b.data", "bar", "tool"} == {
-            p.name for p in foo_dir.iterdir
+            p.name for p in foo_dir.iterdir()
         }
 
         tool = foo_dir["tool"]
@@ -328,9 +328,9 @@ def test_multi_dest_install_rules(manifest_parser_pkg_foo) -> None:
 
         bar = foo_dir["bar"]
         assert bar.is_dir
-        assert {"bar-a.data", "bar-b.data"} == {p.name for p in bar.iterdir}
+        assert {"bar-a.data", "bar-b.data"} == {p.name for p in bar.iterdir()}
         assert {"/nowhere/bar/bar-a.data", "/nowhere/bar/bar-b.data"} == {
-            p.fs_path for p in bar.iterdir
+            p.fs_path for p in bar.iterdir()
         }
 
 
@@ -408,14 +408,14 @@ def test_install_rules_with_glob(manifest_parser_pkg_foo) -> None:
     assert tool.is_symlink
     assert tool.readlink() == "./foo"
 
-    assert {"foo", "foo-util", "tool"} == {p.name for p in ub_dir.iterdir}
+    assert {"foo", "foo-util", "tool"} == {p.name for p in ub_dir.iterdir()}
     usf_dir = foo_fs_root.lookup("/usr/share/foo")
     assert usf_dir is not None
     assert usf_dir.is_dir
     # Here we are installing an actual directory, so it should be present too
     assert usf_dir.has_fs_path
     assert usf_dir.fs_path == "/nowhere/debian/tmp/usr/share/foo"
-    assert {"foo.txt"} == {p.name for p in usf_dir.iterdir}
+    assert {"foo.txt"} == {p.name for p in usf_dir.iterdir()}
 
 
 def test_install_rules_auto_discard_rules_dir(manifest_parser_pkg_foo) -> None:
@@ -477,7 +477,7 @@ def test_install_rules_auto_discard_rules_dir(manifest_parser_pkg_foo) -> None:
     assert so_file.has_fs_path
     assert so_file.fs_path == "/nowhere/debian/tmp/usr/lib/libfoo.so.1.0.0"
 
-    assert {"libfoo.so.1.0.0"} == {p.name for p in lib_dir.iterdir}
+    assert {"libfoo.so.1.0.0"} == {p.name for p in lib_dir.iterdir()}
 
 
 def test_install_rules_auto_discard_rules_glob(manifest_parser_pkg_foo) -> None:
@@ -537,7 +537,7 @@ def test_install_rules_auto_discard_rules_glob(manifest_parser_pkg_foo) -> None:
     assert so_file.has_fs_path
     assert so_file.fs_path == "/nowhere/debian/tmp/usr/lib/libfoo.so.1.0.0"
 
-    assert {"libfoo.so.1.0.0"} == {p.name for p in lib_dir.iterdir}
+    assert {"libfoo.so.1.0.0"} == {p.name for p in lib_dir.iterdir()}
 
 
 def test_install_rules_auto_discard_rules_overruled_by_explicit_install_rule(
@@ -618,7 +618,7 @@ def test_install_rules_auto_discard_rules_overruled_by_explicit_install_rule(
     assert so_link.readlink() == "libfoo.so.1.0.0"
 
     assert {"libfoo.so.1.0.0", "libfoo.so", "libfoo.la"} == {
-        p.name for p in lib_dir.iterdir
+        p.name for p in lib_dir.iterdir()
     }
 
 
@@ -844,9 +844,9 @@ def test_install_rules_per_package_search_dirs(manifest_parser_pkg_foo_w_udeb) -
         assert tool.is_symlink
         assert tool.readlink() == "./foo"
 
-        assert {"foo", "foo-util", "tool"} == {p.name for p in ub_dir.iterdir}
+        assert {"foo", "foo-util", "tool"} == {p.name for p in ub_dir.iterdir()}
 
-        for p in ub_dir.iterdir:
+        for p in ub_dir.iterdir():
             assert p.has_fs_path
             assert f"/nowhere/debian/tmp-{ptype}/usr/bin" in p.fs_path
 
@@ -856,7 +856,7 @@ def test_install_rules_per_package_search_dirs(manifest_parser_pkg_foo_w_udeb) -
         # Here we are installing an actual directory, so it should be present too
         assert usf_dir.has_fs_path
         assert usf_dir.fs_path == f"/nowhere/debian/tmp-{ptype}/usr/share/foo"
-        assert {"foo.txt"} == {p.name for p in usf_dir.iterdir}
+        assert {"foo.txt"} == {p.name for p in usf_dir.iterdir()}
         foo_txt = usf_dir["foo.txt"]
         assert foo_txt.fs_path == f"/nowhere/debian/tmp-{ptype}/usr/share/foo/foo.txt"
 
@@ -937,7 +937,7 @@ def test_install_rules_multi_into(manifest_parser_pkg_foo_w_udeb) -> None:
         assert foo_dir.is_dir
 
         assert {"foo-a.data", "foo-b.data", "bar", "tool"} == {
-            p.name for p in foo_dir.iterdir
+            p.name for p in foo_dir.iterdir()
         }
 
         tool = foo_dir["tool"]
@@ -957,9 +957,9 @@ def test_install_rules_multi_into(manifest_parser_pkg_foo_w_udeb) -> None:
 
         bar = foo_dir["bar"]
         assert bar.is_dir
-        assert {"bar-a.data", "bar-b.data"} == {p.name for p in bar.iterdir}
+        assert {"bar-a.data", "bar-b.data"} == {p.name for p in bar.iterdir()}
         assert {"/nowhere/bar/bar-a.data", "/nowhere/bar/bar-b.data"} == {
-            p.fs_path for p in bar.iterdir
+            p.fs_path for p in bar.iterdir()
         }
 
 
@@ -1062,14 +1062,14 @@ def test_auto_install_d_pkg(manifest_parser_pkg_foo_w_udeb) -> None:
         assert ub_dir.has_fs_path
         assert ub_dir.fs_path == f"/nowhere/debian/{pkg}/usr/bin"
 
-        assert {"foo", "foo-util", "tool"} == {p.name for p in ub_dir.iterdir}
+        assert {"foo", "foo-util", "tool"} == {p.name for p in ub_dir.iterdir()}
 
         tool = ub_dir.get("tool")
         assert tool is not None
         assert tool.is_symlink
         assert tool.readlink() == "./foo"
 
-        for p in ub_dir.iterdir:
+        for p in ub_dir.iterdir():
             assert p.has_fs_path
             assert f"/nowhere/debian/{pkg}/usr/bin" in p.fs_path
 
@@ -1079,7 +1079,7 @@ def test_auto_install_d_pkg(manifest_parser_pkg_foo_w_udeb) -> None:
         # Here we are installing an actual directory, so it should be present too
         assert usf_dir.has_fs_path
         assert usf_dir.fs_path == f"/nowhere/debian/{pkg}/usr/share/foo"
-        assert {"foo.txt"} == {p.name for p in usf_dir.iterdir}
+        assert {"foo.txt"} == {p.name for p in usf_dir.iterdir()}
         foo_txt = usf_dir["foo.txt"]
         assert foo_txt.fs_path == f"/nowhere/debian/{pkg}/usr/share/foo/foo.txt"
 
@@ -1143,7 +1143,7 @@ def test_install_doc_rules_ignore_udeb(manifest_parser_pkg_foo_w_udeb) -> None:
     assert foo_dir is not None
     assert foo_dir.is_dir
 
-    assert {"foo-a.txt", "foo-b.txt", "html"} == {p.name for p in foo_dir.iterdir}
+    assert {"foo-a.txt", "foo-b.txt", "html"} == {p.name for p in foo_dir.iterdir()}
 
     foo_a = foo_dir["foo-a.txt"]
     assert foo_a.is_file
@@ -1154,9 +1154,9 @@ def test_install_doc_rules_ignore_udeb(manifest_parser_pkg_foo_w_udeb) -> None:
 
     html_dir = foo_dir["html"]
     assert html_dir.is_dir
-    assert {"bar-a.html", "bar-b.html"} == {p.name for p in html_dir.iterdir}
+    assert {"bar-a.html", "bar-b.html"} == {p.name for p in html_dir.iterdir()}
     assert {"/nowhere/html/bar-a.html", "/nowhere/html/bar-b.html"} == {
-        p.fs_path for p in html_dir.iterdir
+        p.fs_path for p in html_dir.iterdir()
     }
 
     assert "foo-udeb" in result
